@@ -16,7 +16,7 @@
 #include "main.h"
 #include "gdk-helper.h"
 
-#define VERSION "1.1.5"
+#define VERSION "1.1.6"
 
 static gchar version[] = VERSION;
 int distance=0, distancefrom=DISTANCEFROM_TOP;
@@ -93,7 +93,7 @@ panel_set_wm_strut(panel *p)
     default:
         ERR("wrong edge %d. strut won't be set\n", p->edge);
         RET();
-    }		
+    }
     DBG("type %d. width %d. from %d to %d\n", i, data[i], data[4 + i*2], data[5 + i*2]);
 
     XChangeProperty(gdk_helper_display(), p->topxwin, a_NET_WM_STRUT_PARTIAL,
@@ -105,7 +105,7 @@ panel_set_wm_strut(panel *p)
     RET();
 }
 
-static GdkFilterReturn 
+static GdkFilterReturn
 panel_wm_events(GdkXEvent *xevent, GdkEvent *event, panel *p)
 {
     Atom at;
@@ -135,7 +135,7 @@ panel_wm_events(GdkXEvent *xevent, GdkEvent *event, panel *p)
  ****************************************************/
 
 
-static gint 
+static gint
 panel_delete_event(GtkWidget * widget, GdkEvent * event, gpointer data)
 {
     ENTER;
@@ -146,7 +146,7 @@ static gint
 panel_destroy_event(GtkWidget * widget, GdkEvent * event, gpointer data)
 {
     ENTER;
-    // TODO need to cleanup 
+    // TODO need to cleanup
     gtk_main_quit();
     RET(FALSE);
 }
@@ -243,6 +243,18 @@ panel_configure_event(GtkWidget *widget, GdkEventConfigure *event, panel *p)
     RET(FALSE);
 }
 
+static gboolean
+panel_monitors_changed(GdkScreen* s, panel* p)
+{
+    ENTER;
+    p->monitor = gdk_screen_get_primary_monitor(s);
+    calculate_position(p, distance,distancefrom);
+    gdk_window_move_resize(p->topgwin->window, p->ax, p->ay, p->aw, p->ah);
+    if (p->setstrut)
+        panel_set_wm_strut(p);
+    RET(TRUE);
+}
+
 void
 panel_start_gui(panel *p)
 {
@@ -263,7 +275,15 @@ panel_start_gui(panel *p)
     if (p->transparent) {
       g_signal_connect (G_OBJECT (p->topgwin), "configure-event", G_CALLBACK(panel_configure_event), p);
       g_signal_connect (G_OBJECT (p->topgwin), "style-set", G_CALLBACK( panel_style_set), p);
-    } 
+    }
+
+    if (p->on_primary) {
+        GdkDisplay *display = gdk_display_get_default ();
+        GdkScreen *screen = gdk_display_get_screen(display, 0);
+        g_signal_connect ( screen, "monitors-changed", G_CALLBACK(panel_monitors_changed), (gpointer)p );
+        p->monitor = gdk_screen_get_primary_monitor(screen);
+
+    }
     gtk_widget_realize(p->topgwin);
     gdk_window_set_decorations(p->topgwin->window, 0);
     gtk_widget_set_app_paintable(p->topgwin, TRUE);
@@ -306,7 +326,7 @@ panel_start_gui(panel *p)
 
     gdk_window_stick                 ( p->topGdkWindow);
     gdk_window_set_skip_pager_hint   ( p->topGdkWindow, True );
-    gdk_window_set_skip_taskbar_hint ( p->topGdkWindow, True ); 
+    gdk_window_set_skip_taskbar_hint ( p->topGdkWindow, True );
 
     XSelectInput (gdk_helper_display(), GDK_ROOT_WINDOW(), PropertyChangeMask);
     XSelectInput (gdk_helper_display(), p->topxwin, PropertyChangeMask | FocusChangeMask | StructureNotifyMask);
@@ -316,7 +336,8 @@ panel_start_gui(panel *p)
     gdk_window_move_resize(p->topgwin->window, p->ax, p->ay, p->aw, p->ah);
     if (p->setstrut)
         panel_set_wm_strut(p);
-
+    if (p->lower)
+        XLowerWindow(gdk_helper_display(), p->topxwin);
 
     RET();
 }
@@ -339,12 +360,12 @@ panel_parse_global(panel *p)
     p->heighttype = HEIGHT_PIXEL;
     if (p->heighttype == HEIGHT_PIXEL) {
         if (p->height < PANEL_HEIGHT_MIN) {
-	    ERR( "height is bound by %i pixels\n", PANEL_HEIGHT_MIN );
+            ERR( "height is bound by %i pixels\n", PANEL_HEIGHT_MIN );
             p->height = PANEL_HEIGHT_MIN;
-	} else if (p->height > PANEL_HEIGHT_MAX) {
-	    ERR( "height is bound by %i pixels\n", PANEL_HEIGHT_MAX );
+        } else if (p->height > PANEL_HEIGHT_MAX) {
+            ERR( "height is bound by %i pixels\n", PANEL_HEIGHT_MAX );
             p->height = PANEL_HEIGHT_MAX;
-	}
+        }
     }
     panel_start_gui(p);
     RET(1);
@@ -383,8 +404,9 @@ usage()
     ENTER;
     printf("trayer %s - lightweight GTK2+ systray for UNIX desktops\n", version);
     printf("Command line options:\n");
-    printf(" -h  -- print this help and exit:\n");
-    printf(" -v  -- print version and exit:\n");
+    printf(" -h  -- print this help and exit\n");
+    printf(" -v  -- print version and exit\n");
+    printf(" -l  -- lower the window on startup\n");
     printf(" --edge       <left|right|top|bottom|none> (default:bottom) \n");
     printf(" --align      <left|right|center>          (default:center)\n");
     printf(" --margin     <number>                     (default:0)\n");
@@ -397,13 +419,14 @@ usage()
     printf(" --transparent     <true|false>            (default:false)\n");
     printf(" --alpha      <number>                     (default:127)\n");
     printf(" --tint       <int>                        (default:0xFFFFFFFF)\n");
-    printf(" --distance   <number>                     (default:0)\n"); 
+    printf(" --distance   <number>                     (default:0)\n");
     printf(" --distancefrom <left|right|top|bottom>    (default:top) \n");
     printf(" --expand     <false|true>                 (default:true)\n");
     printf(" --padding    <number>                     (default:0)\n");
     printf(" --monitor    <number|primary>             (default:0)\n");
+    printf(" --iconspacing <number>                    (default:0)\n");
 }
-    
+
 void
 handle_error(Display * d, XErrorEvent * ev)
 {
@@ -421,11 +444,11 @@ main(int argc, char *argv[], char *env[])
     int i;
 
     ENTER;
-    setlocale(LC_CTYPE, ""); 
+    setlocale(LC_CTYPE, "");
     gtk_init(&argc, &argv);
-    XSetLocaleModifiers(""); 
+    XSetLocaleModifiers("");
     XSetErrorHandler((XErrorHandler) handle_error);
-    // resolve xatoms 
+    // resolve xatoms
     resolve_atoms();
 
     p = g_new0(panel, 1);
@@ -439,11 +462,13 @@ main(int argc, char *argv[], char *env[])
     p->setdocktype = 1;
     p->setstrut = 0;
     p->transparent = 0;
+    p->icon_spacing = 0;
     p->alpha = 127;
     p->tintcolor = 0xFFFFFFFF;
     p->xtopbg = None;
     p->monitor = 0;
     p->margin = 0;
+    p->on_primary = 0;
 
     for (i = 1; i < argc; i++) {
         if (!strcmp(argv[i], "-h") || !strcmp(argv[i], "--help")) {
@@ -452,6 +477,8 @@ main(int argc, char *argv[], char *env[])
         } else if (!strcmp(argv[i], "-v") || !strcmp(argv[i], "--version")) {
             printf("trayer %s\n", version);
             exit(0);
+        } else if (!strcmp(argv[i], "-l")) {
+            p->lower = 1;
         } else if (!strcmp(argv[i], "--edge")) {
             i++;
             if (i == argc) {
@@ -606,11 +633,18 @@ main(int argc, char *argv[], char *env[])
                 if (g_ascii_isdigit(argv[i][0])) {
                     p->monitor = atoi(argv[i]);
                 } else if (!strcmp(argv[i], "primary")) {
-                    GdkDisplay *display = gdk_display_get_default ();
-                    GdkScreen *screen = gdk_display_get_screen(display, 0);
-                    p->monitor = gdk_screen_get_primary_monitor(screen);
+                    p->on_primary = 1;
                 }
             }
+        } else if (!strcmp(argv[i], "--iconspacing")) {
+            i++;
+            if (i == argc) {
+                ERR( "trayer: missing icon padding parameter value\n");
+                usage();
+                exit(1);
+            } else {
+                p->icon_spacing = atoi(argv[i]);
+            }
         } else {
             printf("trayer: unknown option - %s\n", argv[i]);
             usage();
